AddressModel class

Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

AddressModel({required AddressTypeModel addressType, required String city, required String streetAddress, required CountryModel country})
const
AddressModel.empty(AddressTypeModel addressTypeModel)
factory
AddressModel.fromJson(Map<String, dynamic> json)
factory

Properties

addressType → AddressTypeModel
final
city → String
final
copyWith → _$AddressModelCWProxy

Available on AddressModel, provided by the $AddressModelCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfAddressModel.copyWith(...) or instanceOfAddressModel.copyWith.fieldName(...).
no setter
country → CountryModel
final
countryAndCity → String
no setter
fullAddress → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streetAddress → String
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

isEmpty() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited