ItemPickerTheme class

Inheritance
Annotations
  • @TailorMixinComponent.new()

Constructors

ItemPickerTheme({required EdgeInsets titlePadding, required TextStyle titleStyle, required EdgeInsets errorPadding, required EdgeInsets contentListPadding, required EdgeInsets footerPadding})
const
ItemPickerTheme.dark()
ItemPickerTheme.light()
region Themes

Properties

contentListPadding → EdgeInsets
final
errorPadding → EdgeInsets
final
footerPadding → EdgeInsets
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titlePadding → EdgeInsets
endregion
final
titleStyle → TextStyle
final
type → Object
The extension's type.
no setterinherited

Methods

copyWith({EdgeInsets? titlePadding, TextStyle? titleStyle, EdgeInsets? errorPadding, EdgeInsets? contentListPadding, EdgeInsets? footerPadding}) → ItemPickerTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
inherited
lerp(covariant ThemeExtension<ItemPickerTheme>? other, double t) → ItemPickerTheme
Linearly interpolate with another ThemeExtension object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited