OpenUriRepository class abstract

OpenUriRepository contract which defines the methods of the underlying Open Uri logic used in conjunction with the OpenUriBloc.

Constructors

OpenUriRepository()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openUri(String uri) → Future<void>
The open URI method which should handle any provided URI
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited