SearchCountryCustomBuilders<T> class

Constructors

SearchCountryCustomBuilders({required bool showEmptyWidgetWhenNoResultsAreFound, ItemPickerItemBuilder<T>? itemBuilder, Widget errorBuilder(Exception)?, Widget emptyBuilder()?, Widget separatorBuilder(int index)?})

Properties

emptyBuilder → Widget Function()?
final
errorBuilder → Widget Function(Exception)?
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → ItemPickerItemBuilder<T>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separatorBuilder → Widget Function(int index)?
final
showEmptyWidgetWhenNoResultsAreFound → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited